# Table of Contents

- [retrieving-survey-results](<./retrieving-survey-results.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Retrieving Survey Results](<./Retrieving-Survey-Results.md>)
  - [Overview](<./Retrieving-Survey-Results/Overview.md>)
  - [Prerequisites](<./Retrieving-Survey-Results/Prerequisites.md>)
  - [Step 1: Get the Survey ID](<./Retrieving-Survey-Results/Step-1-Get-the-Survey-ID.md>)
  - [Step 2: Get the Survey Run ID](<./Retrieving-Survey-Results/Step-2-Get-the-Survey-Run-ID.md>)
  - [Step 3: Get Survey Results](<./Retrieving-Survey-Results/Step-3-Get-Survey-Results.md>)
  - [Was this page helpful?](<./Retrieving-Survey-Results/Was-this-page-helpful.md>)
